@@ -209,15 +209,15 @@ void Ispdb::parseResult(const QDomDocument &document)
     qCDebug(ACCOUNTWIZARD_LOG) << "Domains" << mDomains;
     qCDebug(ACCOUNTWIZARD_LOG) << "Name" << mDisplayName << "(" << mDisplayShortName << ")";
     qCDebug(ACCOUNTWIZARD_LOG) << "Imap servers:";
-    foreach (const Server &s, mImapServers) {
+    for (const Server &s : qAsConst(mImapServers)) {
         qCDebug(ACCOUNTWIZARD_LOG) << s.hostname << s.port << s.socketType << s.username << s.authentication;
     }
     qCDebug(ACCOUNTWIZARD_LOG) << "pop3 servers:";
-    foreach (const Server &s, mPop3Servers) {
+    for (const Server &s : qAsConst(mPop3Servers)) {
         qCDebug(ACCOUNTWIZARD_LOG) << s.hostname << s.port << s.socketType << s.username << s.authentication;
     }
     qCDebug(ACCOUNTWIZARD_LOG) << "smtp servers:";
-    foreach (const Server &s, mSmtpServers) {
+    for (const Server &s : qAsConst(mSmtpServers)) {
         qCDebug(ACCOUNTWIZARD_LOG) << s.hostname << s.port << s.socketType << s.username << s.authentication;
     }
     // end section.
